import { __assign, __rest } from './../../external/tslib/tslib.es6.js';
import Flatpickr from 'flatpickr';
import { POSITION, defaultOptions, defaultFlatPickrOption } from './constants.js';
import { localeDictionary } from '../utils/helper.js';

var DatePicker = function () {
  function DatePicker(node, options) {
    var _this = this;

    this._createCalendarWrapper = function () {
      var wrapper = document.createElement('div');
      wrapper.classList.add('personio-datepicker-wrapper');
      wrapper.appendChild(document.createElement('div'));

      if (wrapper.firstChild) {
        wrapper.firstChild.appendChild(document.createElement('div'));
      }

      return wrapper;
    };

    this._findNodeParent = function () {
      var wrapper = _this._node.parentNode;
      wrapper.classList.add('personio-datepicker-input-wrapper');
      return wrapper;
    };

    this._setCalendarWrapperPosition = function () {
      if (_this._position === POSITION.BOTTOM) {
        return;
      }

      var calendarWrapperInfo = _this._calendarWrapper.getBoundingClientRect();

      var nodeParentInfo = _this._nodeParent.getBoundingClientRect();

      if (_this._position === POSITION.TOP) {
        _this._calendarWrapper.style.top = '';
        _this._calendarWrapper.style.bottom = nodeParentInfo.height + "px";
        return;
      }

      if (calendarWrapperInfo.bottom >= window.innerHeight) {
        _this._calendarWrapper.style.top = '';
        _this._calendarWrapper.style.bottom = nodeParentInfo.height + "px";
      }
    };

    this._resetCalendarWrapperPosition = function () {
      var nodeParentInfo = _this._nodeParent.getBoundingClientRect();

      _this._calendarWrapper.style.top = nodeParentInfo.height + "px";
      _this._calendarWrapper.style.bottom = '';
    };

    this._addEventListeners = function () {
      if (!_this._option.disableToggleOnClick) {
        _this._node.addEventListener('click', _this._openDatePicker);

        _this._node.addEventListener('focus', _this._openDatePicker);
      }

      if (!_this._option.disableCloseOnClickOutside) {
        window.document.addEventListener('click', _this._clickOutsideHandler);
      }
    };

    this._clickOutsideHandler = function (_a) {
      var target = _a.target;
      var targetElement = target;

      do {
        if (_this._node === targetElement || _this._calendarWrapper === targetElement) {
          return;
        } // typecasting to prevent flow type checking error


        targetElement = targetElement.parentNode;
      } while (targetElement);

      _this._closeDatePicker();
    };

    this._openDatePicker = function () {
      _this._calendarWrapper.classList.add('show');

      _this._setCalendarWrapperPosition();

      if (_this._node !== document.activeElement) {
        _this._node.focus();
      }
    };

    this._closeDatePicker = function () {
      _this._calendarWrapper.classList.remove('show');

      _this._resetCalendarWrapperPosition();
    };

    this.toggleDatePicker = function () {
      if (_this._calendarWrapper.classList.contains('show')) {
        _this._closeDatePicker();
      } else {
        _this._openDatePicker();
      }
    };

    this.destroy = function () {
      if (!_this._option.disableToggleOnClick) {
        _this._node.removeEventListener('click', _this._openDatePicker);

        _this._node.removeEventListener('focus', _this._openDatePicker);
      }

      if (!_this._option.disableCloseOnClickOutside) {
        window.document.removeEventListener('click', _this._clickOutsideHandler);
      }

      _this._flatPickrInstance.destroy();

      _this._nodeParent.removeChild(_this._calendarWrapper);
    };

    var optionsWithDefault = __assign(__assign({}, defaultOptions), options);

    if (node) {
      var initialDate = optionsWithDefault.initialDate,
          locale = optionsWithDefault.locale,
          onChange_1 = optionsWithDefault.onChange,
          disableCloseOnSelectDate_1 = optionsWithDefault.disableCloseOnSelectDate,
          disableCloseOnClickOutside = optionsWithDefault.disableCloseOnClickOutside,
          disableToggleOnClick = optionsWithDefault.disableToggleOnClick,
          position = optionsWithDefault.position,
          restOption = __rest(optionsWithDefault, ["initialDate", "locale", "onChange", "disableCloseOnSelectDate", "disableCloseOnClickOutside", "disableToggleOnClick", "position"]);

      this._node = node;
      this._nodeParent = this._findNodeParent();
      this._calendarWrapper = this._createCalendarWrapper();

      this._nodeParent.appendChild(this._calendarWrapper);

      var onChangeModified = function (dateArray) {
        if (!disableCloseOnSelectDate_1) {
          _this._closeDatePicker();
        }

        var date = Array.isArray(dateArray) ? dateArray[0] : undefined;
        onChange_1(date);
      };

      var finalOption = __assign(__assign(__assign(__assign({}, defaultFlatPickrOption), restOption), localeDictionary[locale]), {
        onChange: onChangeModified
      });

      this._option = {
        disableToggleOnClick: disableToggleOnClick,
        disableCloseOnClickOutside: disableCloseOnClickOutside
      }; // eslint-disable-next-line @typescript-eslint/ban-ts-comment
      // @ts-ignore Flatpicker does not have a "void" return type

      this._flatPickrInstance = new Flatpickr(this._calendarWrapper.firstChild, finalOption);

      if (initialDate instanceof Date) {
        this._flatPickrInstance.setDate(initialDate);
      }

      this._position = position;

      this._addEventListeners();
    }
  }

  return DatePicker;
}();

export { DatePicker as default };
//# sourceMappingURL=DeprecatedDatePicker.js.map
