import { __extends, __assign } from './../external/tslib/tslib.es6.js';
import { Button } from '@highlight-ui/button';
import { Icon } from '@highlight-ui/icon';
import { parseMetadata } from '@highlight-ui/utils-commons';
import classnames from 'classnames';
import MonthSelectPlugin from 'flatpickr/dist/plugins/monthSelect';
import * as React from 'react';
import TEST_IDS from './constants.js';
import styles from './MonthNavigation.module.scss.js';
import MonthNavigationInput from './MonthNavigationInput/MonthNavigationInput.js';
import { ReactDatePickerRaw } from './ReactDatePickerRaw/ReactDatePickerRaw.js';
var MEDIUM = 'medium';
var SMALL = 'small';
var SIZE_OFFSET = 0;

function getIconSize(size) {
  if (size === SMALL) {
    return 18;
  }

  return 24;
}

function getSize(size) {
  var _a;

  return _a = {}, _a[styles.small] = size === SMALL, _a[styles.medium] = size === MEDIUM, _a;
}

function notCurrentMonth(date) {
  var today = new Date();
  if (date.getFullYear() !== today.getFullYear()) return true;
  return date.getMonth() !== today.getMonth();
}

function getFirstDayOfCurrentMonth() {
  var today = new Date();
  return new Date(today.getFullYear(), today.getMonth(), 1);
}

var MonthNavigation = function (_super) {
  __extends(MonthNavigation, _super);

  function MonthNavigation() {
    var _this = _super !== null && _super.apply(this, arguments) || this; // eslint-disable-next-line react/state-in-constructor


    _this.state = {
      date: getFirstDayOfCurrentMonth()
    };

    _this.handleDateChange = function (date) {
      var onDateChange = _this.props.onDateChange;

      _this.setState({
        date: date
      });

      onDateChange(date);
    };

    _this.decreaseDate = function () {
      var onDateChange = _this.props.onDateChange;
      var date = _this.state.date;

      if (date) {
        var newDate = new Date(date.getTime());
        newDate.setMonth(newDate.getMonth() - 1);

        _this.setState({
          date: newDate
        });

        onDateChange(newDate);
      }
    };

    _this.increaseDate = function () {
      var onDateChange = _this.props.onDateChange;
      var date = _this.state.date;

      if (date) {
        var newDate = new Date(date.getTime());
        newDate.setMonth(newDate.getMonth() + 1);

        _this.setState({
          date: newDate
        });

        onDateChange(newDate);
      }
    };

    _this.onTodayClick = function (e) {
      var onDateChange = _this.props.onDateChange;
      var date = getFirstDayOfCurrentMonth();

      _this.setState({
        date: date
      });

      onDateChange(date);
      window.document.activeElement.blur();

      if (e) {
        e.preventDefault();
      }
    };

    return _this;
  }

  MonthNavigation.prototype.componentDidMount = function () {
    var initialDate = this.props.initialDate;

    if (initialDate) {
      this.setState({
        date: initialDate
      });
    }
  };

  MonthNavigation.prototype.componentDidUpdate = function (_a) {
    var prevSelected = _a.selected;
    var selected = this.props.selected;

    if (selected instanceof Date && typeof prevSelected === 'undefined' || selected instanceof Date && prevSelected instanceof Date && selected.toString() !== prevSelected.toString()) {
      // eslint-disable-next-line react/no-did-update-set-state
      this.setState({
        date: selected
      });
    }
  };

  MonthNavigation.prototype.render = function () {
    var _this = this;

    var _a = this.props,
        size = _a.size,
        onFocus = _a.onFocus,
        onBlur = _a.onBlur,
        metadata = _a.metadata,
        showTodayButton = _a.showTodayButton,
        todayText = _a.todayText,
        // datepicker props
    dateFormat = _a.dateFormat,
        flatpickrOptions = _a.flatpickrOptions,
        locale = _a.locale,
        initialDate = _a.initialDate,
        disableCloseOnSelectDate = _a.disableCloseOnSelectDate,
        disableCloseOnClickOutside = _a.disableCloseOnClickOutside,
        disableToggleOnClick = _a.disableToggleOnClick,
        monthSelectPluginOptions = _a.monthSelectPluginOptions;
    var date = this.state.date;
    return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(ReactDatePickerRaw, {
      onDateChange: this.handleDateChange,
      dateFormat: dateFormat,
      selected: date,
      locale: locale,
      initialDate: initialDate,
      disableCloseOnSelectDate: disableCloseOnSelectDate,
      disableCloseOnClickOutside: disableCloseOnClickOutside,
      disableToggleOnClick: disableToggleOnClick,
      flatpickrOptions: __assign(__assign({}, flatpickrOptions), {
        plugins: [MonthSelectPlugin(__assign({}, monthSelectPluginOptions))]
      })
    }, function (_a) {
      var value = _a.value,
          inputRef = _a.inputRef,
          onChange = _a.onChange;
      return /*#__PURE__*/React.createElement("div", __assign({}, parseMetadata(metadata), {
        className: styles.wrapper
      }), /*#__PURE__*/React.createElement("span", null, /*#__PURE__*/React.createElement("button", {
        type: "button",
        onClick: _this.decreaseDate,
        className: styles.navigationButton,
        "data-test-id": TEST_IDS.MONTH_PICKER_PREVIOUS_BUTTON
      }, /*#__PURE__*/React.createElement(Icon, {
        name: "angle-left",
        size: getIconSize(size),
        className: styles.icon
      })), /*#__PURE__*/React.createElement("button", {
        type: "button",
        onClick: _this.increaseDate,
        className: styles.navigationButton,
        "data-test-id": TEST_IDS.MONTH_PICKER_NEXT_BUTTON
      }, /*#__PURE__*/React.createElement(Icon, {
        name: "angle-right",
        size: getIconSize(size),
        className: styles.icon
      })), /*#__PURE__*/React.createElement(MonthNavigationInput // eslint-disable-next-line @typescript-eslint/ban-ts-comment
      // @ts-ignore refactoring ReactDatePickerRaw not to use LegacyRef is needed
      , {
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore refactoring ReactDatePickerRaw not to use LegacyRef is needed
        ref: inputRef,
        value: value,
        type: "text",
        onChange: onChange,
        onFocus: onFocus,
        onBlur: onBlur,
        size: value.length + SIZE_OFFSET,
        className: classnames(styles.input, getSize(size)),
        "data-test-id": TEST_IDS.MONTH_PICKER_INPUT
      })), showTodayButton && notCurrentMonth(date) && /*#__PURE__*/React.createElement(Button, {
        onClick: _this.onTodayClick,
        variant: "tertiary",
        className: classnames(styles.todayButton, getSize(size)),
        "data-test-id": TEST_IDS.MONTH_PICKER_TODAY_BUTTON
      }, todayText));
    }));
  }; // eslint-disable-next-line react/static-property-placement


  MonthNavigation.defaultProps = {
    size: MEDIUM,
    locale: 'en-GB',
    selected: undefined,
    metadata: undefined,
    initialDate: undefined,
    onFocus: undefined,
    onBlur: undefined,
    disableCloseOnSelectDate: false,
    disableCloseOnClickOutside: false,
    disableToggleOnClick: false,
    dateFormat: 'F YYYY',
    flatpickrOptions: {},
    monthSelectPluginOptions: {
      shorthand: true
    },
    showTodayButton: true,
    todayText: 'Today'
  };
  return MonthNavigation;
}(React.Component);

export { MonthNavigation as default };
//# sourceMappingURL=MonthNavigation.js.map
