import { __extends, __assign } from './../../external/tslib/tslib.es6.js';
import * as React from 'react';
import DatePicker from '../DeprecatedDatePicker/DeprecatedDatePicker.js';
import { transformDateFormat } from '../utils/helper.js';

var ReactDatePickerRaw = function (_super) {
  __extends(ReactDatePickerRaw, _super);

  function ReactDatePickerRaw(props) {
    var _this = _super.call(this, props) || this;

    _this.inputRef = /*#__PURE__*/React.createRef();

    _this.setDateOnCalendarAndInput = function (date) {
      _this.setDateValueWithFormat(date);

      var TRIGGER_ONCHANGE_FOR_PLUGINS = true;

      _this.datePicker._flatPickrInstance.setDate(date, TRIGGER_ONCHANGE_FOR_PLUGINS);
    };

    _this.setDateValueWithFormat = function (date) {
      var dateFormat = _this.props.dateFormat;
      var transformedDateFormat = transformDateFormat(dateFormat);

      _this.setState({
        value: _this.datePicker._flatPickrInstance.formatDate(date, transformedDateFormat)
      });
    };

    _this.onInputChangeHandler = function (e) {
      if (e.target instanceof HTMLInputElement) {
        _this.setState({
          value: e.target.value
        }, function () {
          var value = _this.state.value;
          var _a = _this.props,
              dateFormat = _a.dateFormat,
              onDateChange = _a.onDateChange;
          var isValidDate = value.length === (dateFormat ? dateFormat.length : -1);
          var transformedDateFormat = transformDateFormat(dateFormat);

          var parsedDate = _this.datePicker._flatPickrInstance.parseDate(value, transformedDateFormat);

          var validatedDate = isValidDate ? parsedDate : undefined;
          onDateChange(validatedDate);

          _this.datePicker._flatPickrInstance.setDate(validatedDate);
        });
      }
    };

    _this.onDateChangeHandler = function (date) {
      var onDateChange = _this.props.onDateChange;

      _this.setDateValueWithFormat(date);

      onDateChange(date);
    };

    _this.renderDatePicker = function () {
      var _a = _this.props,
          flatpickrOptions = _a.flatpickrOptions,
          locale = _a.locale,
          initialDate = _a.initialDate,
          disableCloseOnSelectDate = _a.disableCloseOnSelectDate,
          disableCloseOnClickOutside = _a.disableCloseOnClickOutside,
          disableToggleOnClick = _a.disableToggleOnClick,
          position = _a.position;

      var options = __assign(__assign({}, flatpickrOptions), {
        locale: locale,
        initialDate: initialDate,
        disableCloseOnSelectDate: disableCloseOnSelectDate,
        disableCloseOnClickOutside: disableCloseOnClickOutside,
        disableToggleOnClick: disableToggleOnClick,
        position: position,
        onChange: _this.onDateChangeHandler
      });

      if (_this.datePicker) {
        _this.datePicker.destroy();
      } // eslint-disable-next-line @typescript-eslint/ban-ts-comment
      // @ts-ignore migrate the LegacyRef so it will be type checked


      _this.datePicker = new DatePicker(_this.inputRef.current.ref, options);
    };

    _this.state = {
      value: ''
    };
    return _this;
  }

  ReactDatePickerRaw.prototype.componentDidMount = function () {
    this.renderDatePicker();
    var _a = this.props,
        initialDate = _a.initialDate,
        selected = _a.selected;

    if (initialDate instanceof Date) {
      this.setDateValueWithFormat(initialDate);
    }

    if (selected instanceof Date) {
      this.setDateOnCalendarAndInput(selected);
    }
  };

  ReactDatePickerRaw.prototype.componentDidUpdate = function (_a) {
    var prevSelected = _a.selected;
    var selected = this.props.selected;

    if (selected instanceof Date && typeof prevSelected === 'undefined' || selected instanceof Date && prevSelected instanceof Date && selected.toString() !== prevSelected.toString()) {
      this.setDateOnCalendarAndInput(selected);
    }
  };

  ReactDatePickerRaw.prototype.componentWillUnmount = function () {
    this.datePicker.destroy();
  };

  ReactDatePickerRaw.prototype.render = function () {
    var children = this.props.children;
    var value = this.state.value;
    return children({
      value: value,
      inputRef: this.inputRef,
      onChange: this.onInputChangeHandler
    });
  }; // eslint-disable-next-line react/static-property-placement


  ReactDatePickerRaw.defaultProps = {
    locale: 'en-GB',
    selected: undefined,
    initialDate: undefined,
    position: undefined,
    disableCloseOnSelectDate: false,
    disableCloseOnClickOutside: false,
    disableToggleOnClick: false,
    dateFormat: 'DD.MM.YYYY',
    flatpickrOptions: {}
  };
  return ReactDatePickerRaw;
}(React.Component);

export { ReactDatePickerRaw };
//# sourceMappingURL=ReactDatePickerRaw.js.map
